@@ -1,11 +1,13 @@
 package Getopt::Long::Less;
 
-our $DATE = '2015-06-16'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2015-06-17'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
-## use warnings; # COMMENT
+# IFUNBUILT
+# use warnings;
+# END IFUNBUILT
 
 our @EXPORT   = qw(GetOptions);
 our @EXPORT_OK = qw(Configure GetOptionsFromArray);
@@ -291,8 +293,7 @@ sub GetOptions {
     GetOptionsFromArray(\@ARGV, @_);
 }
 
-## require Getopt::Long::Util; *parse_getopt_long_opt_spec = \&Getopt::Long::Util::parse_getopt_long_opt_spec; # COMMENT
-
+# IFBUILT
 sub parse_getopt_long_opt_spec {
     my $optspec = shift;
     $optspec =~ qr/\A
@@ -354,6 +355,11 @@ sub parse_getopt_long_opt_spec {
     \%res;
 }
 
+# END IFBUILT
+# IFUNBUILT
+# require Getopt::Long::Util; *parse_getopt_long_opt_spec = \&Getopt::Long::Util::parse_getopt_long_opt_spec;
+# END IFUNBUILT
+
 package Getopt::Long::Less::Callback;
 
 sub new {
@@ -380,7 +386,7 @@ Getopt::Long::Less - Like Getopt::Long, but with less features
 
 =head1 VERSION
 
-This document describes version 0.04 of Getopt::Long::Less (from Perl distribution Getopt-Long-Less), released on 2015-06-16.
+This document describes version 0.05 of Getopt::Long::Less (from Perl distribution Getopt-Long-Less), released on 2015-06-17.
 
 =head1 DESCRIPTION
 
@@ -415,14 +421,14 @@ milliseconds from startup overhead of my CLI scripts. That's it :-)
 Sample startup overhead benchmark:
 
                        Rate     load_gl load_glless   perl
- load_gl      73.28+-0.49/s          --      -50.9% -88.4%
- load_glless 149.25+-0.24/s 103.7+-1.4%          -- -76.4%
- perl            633.3+-5/s   764.2+-9% 324.3+-3.4%     --
+ load_gl      75.27+-0.33/s          --      -48.5% -88.5%
+ load_glless 146.09+-0.54/s  94.1+-1.1%          -- -77.6%
+ perl          652.8+-2.3/s 767.2+-4.9% 346.8+-2.3%     --
  
  Average times:
-   perl       :     1.5790ms
-   load_glless:     6.7002ms
-   load_gl    :    13.6463ms
+   perl       :     1.5319ms
+   load_glless:     6.8451ms
+   load_gl    :    13.2855ms
 
 =for Pod::Coverage .+
 
